@@ -60,6 +60,7 @@ from hypothesis.internal.floats import (
 )
 from hypothesis.internal.intervalsets import IntervalSet
 from hypothesis.reporting import debug_report
+from hypothesis.utils.conventions import not_set
 
 if TYPE_CHECKING:
     from typing import TypeAlias
@@ -137,7 +138,7 @@ def structural_coverage(label: int) -> StructuralCoverageTag:
 
 # This cache can be quite hot and so we prefer LRUCache over LRUReusedCache for
 # performance. We lose scan resistance, but that's probably fine here.
-POOLED_CONSTRAINTS_CACHE = LRUCache(4096)
+POOLED_CONSTRAINTS_CACHE: LRUCache[tuple[Any, ...], ChoiceConstraintsT] = LRUCache(4096)
 
 
 class Span:
@@ -707,6 +708,7 @@ class ConjectureData:
             tuple[str, object]
         ] = None
         self._shared_strategy_draws: dict[Hashable, Any] = {}
+        self.hypothesis_runner = not_set
 
         self.expected_exception: Optional[BaseException] = None
         self.expected_traceback: Optional[str] = None
@@ -976,17 +978,10 @@ class ConjectureData:
             if node.type == "simplest":
                 if forced is not None:
                     choice = forced
-                elif isinstance(self.provider, HypothesisProvider):
-                    try:
-                        choice = choice_from_index(0, choice_type, constraints)
-                    except ChoiceTooLarge:
-                        self.mark_overrun()
-                else:
-                    # give alternative backends control over ChoiceTemplate draws
-                    # as well
-                    choice = getattr(self.provider, f"draw_{choice_type}")(
-                        **constraints
-                    )
+                try:
+                    choice = choice_from_index(0, choice_type, constraints)
+                except ChoiceTooLarge:
+                    self.mark_overrun()
             else:
                 raise NotImplementedError
 
