@@ -992,9 +992,13 @@ class DataTree:
 
 class TreeRecordingObserver(DataObserver):
     def __init__(self, tree: DataTree):
-        self.__current_node: TreeNode = tree.root
-        self.__index_in_current_node: int = 0
-        self.__trail: list[TreeNode] = [self.__current_node]
+        # this attr isn't read, but is very useful for local debugging flaky
+        # errors, with
+        # `from hypothesis.vendor import pretty; print(pretty.pretty(self._root))`
+        self._root = tree.root
+        self._current_node: TreeNode = tree.root
+        self._index_in_current_node: int = 0
+        self._trail: list[TreeNode] = [self._current_node]
         self.killed: bool = False
 
     def draw_integer(
@@ -1034,9 +1038,9 @@ class TreeRecordingObserver(DataObserver):
         was_forced: bool,
         constraints: ChoiceConstraintsT,
     ) -> None:
-        i = self.__index_in_current_node
-        self.__index_in_current_node += 1
-        node = self.__current_node
+        i = self._index_in_current_node
+        self._index_in_current_node += 1
+        node = self._current_node
 
         if isinstance(value, float):
             value = float_to_int(value)
@@ -1062,8 +1066,8 @@ class TreeRecordingObserver(DataObserver):
                 new_node = TreeNode()
                 assert isinstance(node.transition, Branch)
                 node.transition.children[value] = new_node
-                self.__current_node = new_node
-                self.__index_in_current_node = 0
+                self._current_node = new_node
+                self._index_in_current_node = 0
         else:
             trans = node.transition
             if trans is None:
@@ -1094,8 +1098,8 @@ class TreeRecordingObserver(DataObserver):
                 ):
                     node.split_at(i)
                     assert isinstance(node.transition, Branch)
-                    self.__current_node = node.transition.children[value]
-                    self.__index_in_current_node = 0
+                    self._current_node = node.transition.children[value]
+                    self._index_in_current_node = 0
             elif isinstance(trans, Conclusion):
                 assert trans.status != Status.OVERRUN
                 # We tried to draw where history says we should have
@@ -1106,12 +1110,12 @@ class TreeRecordingObserver(DataObserver):
                 if choice_type != trans.choice_type or constraints != trans.constraints:
                     raise FlakyStrategyDefinition(_FLAKY_STRAT_MSG)
                 try:
-                    self.__current_node = trans.children[value]
+                    self._current_node = trans.children[value]
                 except KeyError:
-                    self.__current_node = trans.children.setdefault(value, TreeNode())
-                self.__index_in_current_node = 0
-        if self.__trail[-1] is not self.__current_node:
-            self.__trail.append(self.__current_node)
+                    self._current_node = trans.children.setdefault(value, TreeNode())
+                self._index_in_current_node = 0
+        if self._trail[-1] is not self._current_node:
+            self._trail.append(self._current_node)
 
     def kill_branch(self) -> None:
         """Mark this part of the tree as not worth re-exploring."""
@@ -1120,19 +1124,19 @@ class TreeRecordingObserver(DataObserver):
 
         self.killed = True
 
-        if self.__index_in_current_node < len(self.__current_node.values) or (
-            self.__current_node.transition is not None
-            and not isinstance(self.__current_node.transition, Killed)
+        if self._index_in_current_node < len(self._current_node.values) or (
+            self._current_node.transition is not None
+            and not isinstance(self._current_node.transition, Killed)
         ):
             raise FlakyStrategyDefinition(_FLAKY_STRAT_MSG)
 
-        if self.__current_node.transition is None:
-            self.__current_node.transition = Killed(TreeNode())
+        if self._current_node.transition is None:
+            self._current_node.transition = Killed(TreeNode())
             self.__update_exhausted()
 
-        self.__current_node = self.__current_node.transition.next_node
-        self.__index_in_current_node = 0
-        self.__trail.append(self.__current_node)
+        self._current_node = self._current_node.transition.next_node
+        self._index_in_current_node = 0
+        self._trail.append(self._current_node)
 
     def conclude_test(
         self, status: Status, interesting_origin: Optional[InterestingOrigin]
@@ -1141,8 +1145,8 @@ class TreeRecordingObserver(DataObserver):
         node if necessary and checks for consistency."""
         if status == Status.OVERRUN:
             return
-        i = self.__index_in_current_node
-        node = self.__current_node
+        i = self._index_in_current_node
+        node = self._current_node
 
         if i < len(node.values) or isinstance(node.transition, Branch):
             raise FlakyStrategyDefinition(_FLAKY_STRAT_MSG)
@@ -1168,7 +1172,7 @@ class TreeRecordingObserver(DataObserver):
         else:
             node.transition = new_transition
 
-        assert node is self.__trail[-1]
+        assert node is self._trail[-1]
         node.check_exhausted()
         assert len(node.values) > 0 or node.check_exhausted()
 
@@ -1176,7 +1180,7 @@ class TreeRecordingObserver(DataObserver):
             self.__update_exhausted()
 
     def __update_exhausted(self) -> None:
-        for t in reversed(self.__trail):
+        for t in reversed(self._trail):
             # Any node we've traversed might have now become exhausted.
             # We check from the right. As soon as we hit a node that
             # isn't exhausted, this automatically implies that all of
